@@ -1,8 +1,8 @@
 from datetime import datetime
 
-from twisted.internet import reactor
 from scrapy.settings import Settings
 from scrapy.crawler import CrawlerRunner
+from twisted.internet import defer
 
 from .spiders.ote_electricity import DayMarketPricesSpider
 
@@ -15,6 +15,8 @@ class Ote:
         self._settings = Settings()
         self._settings.setmodule('ote.settings', priority='project')
 
+        self._runner = CrawlerRunner(self._settings)
+
         # Override settings if needed
         if log_enabled is not None:
             self._settings["LOG_ENABLED"] = log_enabled
@@ -26,20 +28,23 @@ class Ote:
             is not specified return consumption data from `date_from` till today.
 
             `date_from` and `date_to` must be datetime.date-compatible objects.
+
+            Returns a `twisted.internet.defer.Deferred` that will return
         """
-        items = []
+        prices = {}
 
         def _item_scraped(item):
-            items.append(item)
+            prices[datetime.combine(item["date"], item["time"]).isoformat()] = item["price"]
 
-        runner = CrawlerRunner(self._settings)
-        deferred = runner.crawl(
+        deferred_results = defer.Deferred()
+        deferred_crawl = self._runner.crawl(
             DayMarketPricesSpider,
             date_from=date_from,
             date_to=date_to,
             cb_item_scraped=_item_scraped,
         )
-        deferred.addBoth(lambda _: reactor.stop())
-        reactor.run(installSignalHandlers=False)  # the script will block here until the crawling is finished
+        deferred_crawl.addCallback(lambda _: deferred_results.callback(prices))
+        return deferred_results
 
-        return {datetime.combine(item["date"], item["time"]).isoformat(): item["price"] for item in items}
+    def join(self):
+        return self._runner.join()
